PrimaryKeyToColumn

Trait PrimaryKeyToColumn 

pub trait PrimaryKeyToColumn {
    type Column: ColumnTrait;

    // Required methods
    fn into_column(self) -> Self::Column;
    fn from_column(col: Self::Column) -> Option<Self>
       where Self: Sized;
}
How to map a Primary Key to a column

Required Associated Types

Required Methods

fn into_column(self) -> Self::Column

Method to map a primary key to a column in an Entity

fn from_column(col: Self::Column) -> Option<Self>
where Self: Sized,

Method to map a primary key from a column in an Entity

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl PrimaryKeyToColumn for PrimaryKey

Implementors